#!/usr/bin/perl

###################################################################
#                PureSecure Console Configuration                 #
###################################################################
#                                                                 #
# Copyright 2001-2002, Demarc Security, Inc. All rights reserved. #
# Please see the included LICENSE file, visit http://demarc.com/  #
# or email license@demarc.com for full license details            #
#                                                                 #
###################################################################

###################################################################
package puresecure_config;
use strict;
sub get_config_hash{
my %conf;
###################################################################


#------------------------------------------------------------------
# Database Variables
#------------------------------------------------------------------
# You MUST change these to match a valid account on your database.
# The database user must have insert/update and drop priviledges.

$conf{'db_user'} = "snort";
$conf{'db_passwd'} = "your_password";
$conf{'db_host'} = "127.0.0.1";
$conf{'db_name'} = "snort";
$conf{'db_port'} = "3306";


#----------------------------------------------------------------
# Paths and File Locations
#----------------------------------------------------------------
# The path to your binaries on this system are automatically
# detected when the console runs, however if they are not found
# they will be ignored.  

$conf{'whois_command'}       = "/usr/bin/whois";
$conf{'traceroute_command'}  = "/usr/sbin/traceroute";
$conf{'dig_command'}         = "/usr/bin/dig";
$conf{'nslookup_command'}    = "/usr/sbin/nslookup";
$conf{'ping_command'}        = "/usr/sbin/ping";
$conf{'nmap_command'}        = "/usr/local/bin/nmap";
$conf{'nmap_options'}        = "-T5 -P0";
#$conf{'snort_binary'}       = "/usr/local/bin/snort";


#----------------------------------------------------------------
# Use Cache
#----------------------------------------------------------------
# Turn on database caching in order to speed up certain results
# Set to "1" to turn on, "0" to turn off.

$conf{'use_cache'} = "1";


#----------------------------------------------------------------
# DBI Mod_Perl
#----------------------------------------------------------------
# This is an optional module, but is suggested if you are using mod_perl
# db connection management

$conf{'use_Apache_DBI_with_mod_perl'}  = "0";


#----------------------------------------------------------------
# Anonymous Users
#----------------------------------------------------------------
# Allow anonymous users to access the console. 
# Set to "1" to allow, "0" to disallow.

$conf{'allow_anonymous_access'} = "1";


#----------------------------------------------------------------
# Quick Stats Configuration
#----------------------------------------------------------------
#

$conf{'last_event_only_show_above_level'}	= 1; #0 for Any.  1-10 for events on or above level.
$conf{'qs_monitored_events_limit'}			= 4; #Number of hours to show in "Last X Hours" table.
$conf{'qs_hours_to_show'}					= 6;
$conf{'qs_alerts_per_sensor_max_shown'}		= 11; #0 to turn off.
$conf{'qs_top_src_ips_cutoff_hours'}		= 24;
$conf{'qs_top_dst_ips_cutoff_hours'}		= 24;
$conf{'qs_top_src_ips'}						= 8;
$conf{'qs_top_dst_ips'}						= 4;


#----------------------------------------------------------------
# Summary Page Configurations
#----------------------------------------------------------------
#

$conf{'last_events_limit'}				= 6; #Number of events to show on summary page
$conf{'unique_events_type'}				= "hour"; #Options: "day" or "hour"
$conf{'unique_events_offset'}			= 12; #Any number of hours or days (depending on above)
$conf{'unique_events_limit'}			= 6; #Number of result rows to show
$conf{'service_events_limit'}			= 6; #Number of recent service/host events shown on summary page - 0 to disable
$conf{'hide_maint_alerts_on_summary_page'} = 1; #1 to have Maintenance alerts (gray) not show up on summary page
$conf{'hide_cached_messages'}			= 0; #Enable to hide cached messages (has no effect on caching process)


#----------------------------------------------------------------
# Preproccessor Display
#----------------------------------------------------------------
# Shorten "spp_preprocessor" to "spp:"  as a display enchancement
# Set to "1" to show, and "0" to shorten.

$conf{'show_spp_prefix_in_signature'} = "0";


#----------------------------------------------------------------
# ArachNIDS URL
#----------------------------------------------------------------
# URL to retreive arachNIDS database information from

$conf{'arachnids_uri'}	= "http://demarc.com/arachnids/IDS";







##################################################################
##################################################################
## If you followed the installation instructions, you shouldn't ##
## have to change anything below here.                          ##
##################################################################
##################################################################





#----------------------------------------------------------------
# Base Path
#----------------------------------------------------------------
# Base path where the PureSecure is installed

#$conf{'base_path'}  = "/usr/local/puresecure";


#----------------------------------------------------------------
# Virtual Base Path
#----------------------------------------------------------------
# Virtual base path where the PureSecure cgi is contained

$conf{'v_base_path'}  = "/Demarc";


#----------------------------------------------------------------
# Decode MIME
#----------------------------------------------------------------
# Automatically decode MIME basic authentication in payload
# Set to "1" to decode, and "0" to not decode.

$conf{'detect_basic_auth'} = "1";


#----------------------------------------------------------------
# Default Event List Limit
#----------------------------------------------------------------
# Sets the default limit of events per page.

$conf{'default_limit'}  = "60";


#----------------------------------------------------------------
# Modify Email Address
#----------------------------------------------------------------
# Allow regular users to change their email address for their account,
# administrators can always cahnge their email address.
# Set to "1" to allow, and "0" to disallow.

$conf{'allow_user_to_change_email'}  = "1"; 


#----------------------------------------------------------------
# IP Validation
#----------------------------------------------------------------
# Make sure that the session ID comes from the same IP address every time
# Note: Only change if you are having problems with people
#       checking from proxies like AOL where IPs appear to change
#       over the course of a single session
# Set to "1" to make sure, and "0" to allow any IP.

$conf{'validate_ip'} = "1"; 


#----------------------------------------------------------------
# Anonymous Admin -- DO NOT LEAVE THIS ON
#----------------------------------------------------------------
# Make the anonymous user an Admin. 
# *DO NOT UNDER ANY CIRCUMSTANCES LEAVE THIS ON*
# Set to "1" to make anonymous user admin, and "0" elsewise.

$conf{'anonymous_user_is_admin'}  = "0";


#----------------------------------------------------------------
# Session Timeout
#----------------------------------------------------------------
# Number of idle minutes before a users session times out

$conf{'session_timeout_minutes'} = "30";


#----------------------------------------------------------------
# HTTPS Bypass
#----------------------------------------------------------------
# You should always run your console under HTTPS
# Not doing so is likely to cause a feedback loop of
# alerts, as well as put your password at risk.
# This option should be used for testing purposes
# only.
# Set to "0" for HTTPS, and "1" for HTTP 

$conf{'bypass_admin_lockout_on_no_ssl'}  = "0";


#----------------------------------------------------------------
# Caching
#----------------------------------------------------------------
# Amount of time in minutes to cache statistics in database

$conf{'allowed_cache_minutes'} = "4";
$conf{'allowed_long_cache_minutes'} = "30";


#----------------------------------------------------------------
# Timestamp Format
#----------------------------------------------------------------
# "12" for 12 hour timestamp formatting
# "24" for 24 hour timestamp formatting

$conf{'timestamp_format'} = "12";



#################################################################
return %conf;
}
1;
#################################################################
