#!/usr/bin/perl

###################################################################
#                                                                 #
# Copyright 2001-2002, Demarc Security, Inc. All rights reserved. #
# Please see the included LICENSE file, visit http://demarc.com/  #
# or email license@demarc.com for full license details.           #
#                                                                 #
###################################################################

use DBI;
use DBD::mysql;
use vars qw ( $db @del_array );


my @tables_array = ('data','event','icmphdr','tcphdr','udphdr','iphdr','opt');
print << "EOF";
---------------------------------------------------------------
Remove Network Events from the Database             
---------------------------------------------------------------
By following the prompts, you will be able to optionally 
delete network IDS events stored in your database, by the 
number of days, a specific signature, or all events in total.

EOF

print "Database User? [root] > ";
chomp (my $db_user = <STDIN>);
($db_user) || ($db_user = "root");
print "Database Password? > ";
chomp (my $db_password = <STDIN>);
print "Database Host? [localhost] > ";
chomp (my $db_host  = <STDIN>);
($db_host) || ($db_host = "localhost");
print "Database Name? [IDS] > ";
chomp (my $db_name    = <STDIN>);
($db_name) || ($db_name = "IDS");

print << "EOF";

User: $db_user
Password: $db_password
Host: $db_host
Name: $db_name

EOF
print "Is this correct? [y/N] >";

chomp($huh = <STDIN>);
if ($huh!~/y/i){
	die "OK, come back later when you're ready.\n";
}
&connect_to_db || &error("Invalid credentials, please try again.");


print << "EOF";
---------------------------------------------------------------
Select an Action
---------------------------------------------------------------

1) Delete ALL snort events from the database
2) Delete snort events in the past "x" days
3) Delete snort events matching a signature containing [portion]

EOF

print " [1/2/3] > ";
chomp($ans=<STDIN>);

if ($ans=~/^1$/){
print << "EOF";
---------------------------------------------------------------
IMPORTANT NOTE
---------------------------------------------------------------
THIS WILL DELETE ALL SNORT EVENTS IN YOUR DATABASE!

This should ONLY be used if your database has grown too large 
to delete normally.
---------------------------------------------------------------

EOF


print "Are you SURE you want to delete ALL snort data in this database? (you must TYPE OUT \"yes\" or this script will abort) [yes/NO] > ";

chomp (my $confirmed    = <STDIN>);

die "Script aborting\n" unless ($confirmed=~/^yes$/i);


my $sql_query;
foreach (@tables_array){
	$sql_query = "DELETE FROM $_";
	print "DELETE FROM $_\n";
	$db_ptr = &run_query($sql_query);
}


&optimize;


}
elsif ($ans=~/^2$/){


$ans='';
print "How many days back would you like to clear from the DB? > ";
chomp($ans=<STDIN>);
die "Invalid entry \"$ans\"\n" unless ($ans=~/^\d+$/);
 


my $sql_query = "SELECT sid,cid FROM event WHERE timestamp > DATE_ADD(NOW(), INTERVAL -$ans DAY)";
$db_ptr = &run_query($sql_query);
while ($hash_ref = $db_ptr->fetchrow_hashref){
        push (@del_array,"$$hash_ref{'sid'},$$hash_ref{'cid'}");
}

my $dcount = (@del_array);

print "There are $dcount matching events...\n";
print "Are you SURE you want to delete Snort data from the past $ans days in this database? \n";
print "(you must TYPE OUT \"yes\" or this script will abort) [yes/NO] > ";

chomp (my $confirmed    = <STDIN>);

die "Script aborting\n" unless ($confirmed=~/^yes$/i);

&delete_events;

}
elsif ($ans=~/^3$/){


$ans='';
print "Please enter the full or partial signature that you would like to delete. > ";
chomp($ans=<STDIN>);
die "Invalid entry \"$ans\"\n" unless ($ans=~/\S/);
 


my $sql_query = "	SELECT sid,cid FROM event LEFT JOIN signature ON event.signature = signature.sig_id WHERE sig_name 
					LIKE '%$ans%'";
$db_ptr = &run_query($sql_query);
while ($hash_ref = $db_ptr->fetchrow_hashref){
        push (@del_array,"$$hash_ref{'sid'},$$hash_ref{'cid'}");
}

my $dcount = (@del_array);

print "There are $dcount matching events...\n";
print "Are you SURE you want to delete Snort data matching signature \"$ans\"? \n";
print "(you must TYPE OUT \"yes\" or this script will abort) [yes/NO] > ";

chomp (my $confirmed    = <STDIN>);

die "Script aborting\n" unless ($confirmed=~/^yes$/i);

&delete_events;

}
#############################################
# Functions
#############################################
sub delete_events{

(@del_array) || die "No events found to delete!\n";

foreach $line(@del_array){
my @d_a = split(/,/,$line);
next unless (($d_a[0]=~/^\d+$/) && ($d_a[1]=~/^\d+$/));

foreach (@tables_array){
	$sql_query = "DELETE FROM $_ WHERE sid='$d_a[0]' AND cid='$d_a[1]'";
	$db_ptr = &run_query($sql_query);
	$cc++ if ($_=~/event/);
}

}

print "$cc events deleted.\n";

&optimize;

exit;
}
##############################
sub run_query{
my ($sql_query) = @_;
&connect_to_db();
$q_count++;
print ".";

my $prepared = $db->prepare($sql_query);
if (!$prepared){
        #Then there's an error with the syntax of the query:
        &error("Syntax Error in SQL Query:\n$sql_query\n:\n".$db->errstr);
}
my $dbquery = $prepared->execute();
if (my $error_string = $prepared->errstr){
        &error("$error_string : $sql_query");
}
return $prepared;
}
#####################
sub connect_to_db{
if (!$db || !$db->ping){

# function args override defaults, but error out if neither are there.
 $db_user         ||  &error("No database user specified.");
 $db_password     ||  &error("No database password specified.");
 $db_host         ||  &error("No database host specified.");
 $db_name         ||  &error("No database specified.");

 $db = DBI->connect("dbi:mysql:host=$db_host;database=$db_name", $db_user , $db_password) || &error("Connection Problem! ". $DBI::errstr);

}
return $db;
}
####################
sub error{
my ($le) = @_;
die "$le\n";
}
##################
sub safe_slash{
my ($string_ref) = @_;

$$string_ref=~s/(['\\])/\\$1/g;

}
#################
sub optimize{
print "#"x60 . "\n";
print "Please standby while the tables are being optimized...\n\n";

foreach (@tables_array){
	$sql_query = "OPTIMIZE TABLE $_";
	$db_ptr = &run_query($sql_query);
}

print "Optimizations done.\n";
print "#"x60 . "\n\n\n";
}
